@@ -56,7 +56,7 @@ class TestEncryption(TestCase):
         assert key == b'n\x88\xbe\x8b\xad~\xae\x9d\x9e\x10\xaa\x06\x12$\x03O', key
 
     def test_expand(self):
-        key1, key2 = _expand_keys('password', b'salt')
+        key1, key2 = _expand_keys('password', b'salt', 10000)
         assert key1 != key2
         assert key1 == b'^\xc0+\x91\xa4\xb5\x9coY\xdd_\xbeL\xa6I\xec\xe4\xfa\x85h\xcd\xb8\xba6\xcfABn\x88\x05R+', key1
         assert len(key1) * 8 == 256, len(key1)
@@ -187,6 +187,12 @@ class TestBackwardsCompatibility(TestCase):
         ptext = decrypt('password', ctext)
         assert ptext == b'message', ptext
 
+    def test_known_2(self):
+        # this was generated with python 3.3 and v4.0.0
+        ctext = b'sc\x00\x02g)x\x7f\xbf\xc8\xe5\xff\roR\x9b\x0e#X\xb8eW=\x93,\x85I{\x9a{\x9d\x07\xf4TUj\xfek/\xed\xff\xde\xaa|\\`\x1a\xc1\xf9\x81\x12\x0blE\r$\x827\x1b\xe9Gz\xf2\x87T\xd1gW\x9ez\xd9Y{\x80\x1a'
+        ptext = decrypt('password', ctext)
+        assert ptext == b'message', ptext
+
 
 try:
 
